## Text Classification Triton Model Examples

These can be used on the fly with minimal or no changes to test deploy text classification models to the Clarifai platform. See the required files section for each model below.

* ### [XLM-Roberta Tweet Sentiment Classifier](./xlm-roberta/)

	Required files to run tests locally:

	* Download the [model checkpoint & sentencepiece bpe model from huggingface](https://huggingface.co/cardiffnlp/twitter-xlm-roberta-base-sentiment/tree/main) and store it under `xlm-roberta/1/twitter-xlm-roberta-base-sentiment/`
